@@ -84,7 +84,7 @@ RunRMDEFF <- function(efficacy.dat = NULL, toxicity.dat, trialSize = 36,
                                p1_tau_e = 0, p2_tau_e = 1000, 
                                p1_tau_u = 0, p2_tau_u = 1000)
                 path.model <- file.path(tempdir(), "model.file.txt")
-                R2WinBUGS::write.model(model.file, path.model)
+                #R2WinBUGS::write.model(model.file, path.model)
                 
                 inits.list <- list(list(beta_other = c(0.1, 0.1),
                                         beta_dose = 0.1,
@@ -381,7 +381,7 @@ RunRMDEFF <- function(efficacy.dat = NULL, toxicity.dat, trialSize = 36,
                                p1_tau_u = 0, p2_tau_u = 1000, 
                                p1_tau_f = 0, p2_tau_f = 1000)
                 path.model <- file.path(tempdir(), "model.file.txt")
-                R2WinBUGS::write.model(model.file, path.model)
+                #R2WinBUGS::write.model(model.file, path.model)
                 
                 inits.list <- list(list(beta_other = c(0.1, 0.1),
                                         beta_dose = 0.1,
@@ -610,7 +610,7 @@ RunRMDEFF <- function(efficacy.dat = NULL, toxicity.dat, trialSize = 36,
                                p1_tau_u = 0, p2_tau_u = 1000, 
                                p1_tau_f = 0, p2_tau_f = 1000)
                 path.model <- file.path(tempdir(), "model.file.txt")
-                R2WinBUGS::write.model(model.file, path.model)
+                #R2WinBUGS::write.model(model.file, path.model)
                 
                 inits.list <- list(list(beta_other = c(0.1, 0.1),
                                         beta_dose = 0.1,
