@@ -311,8 +311,8 @@ if (loss.fun == 'default'){
 	}
     obsDLT[k] <- sum(patData[,"DLT"])
     actSize[k] <- cmPat
-    try(write.table(recMat, file=paste(pathout, "/", k, "/recMat.txt", sep="")), silent=T)
-	try(write.table(alcMat, file=paste(pathout, "/", k, "/alcMat.txt", sep="")), silent=T)
+    #try(write.table(recMat, file=paste(pathout, "/", k, "/recMat.txt", sep="")), silent=T)
+	#try(write.table(alcMat, file=paste(pathout, "/", k, "/alcMat.txt", sep="")), silent=T)
     # write.table(dropMat_DLT, file=paste(pathout, "/", k, "/dropMat_DLT.txt", sep=""))   
 	# write.table(dropMat_RND, file=paste(pathout, "/", k, "/dropMat_RND.txt", sep=""))
 	# write.table(dropMat_all, file=paste(pathout, "/", k, "/dropMat_all.txt", sep=""))
@@ -324,14 +324,14 @@ if (loss.fun == 'default'){
 
 
   #debug
-  try(write.table(rec_patData,file=paste(pathout,'/patData.txt',sep='')), silent=T);
+  #try(write.table(rec_patData,file=paste(pathout,'/patData.txt',sep='')), silent=T);
   #debug
 
   #debug
-  try(write.table(alcMat,file=paste(pathout,'/alcMat.txt',sep='')), silent=T);
+  #try(write.table(alcMat,file=paste(pathout,'/alcMat.txt',sep='')), silent=T);
   #debug
 
-  try(write.table(recMat,file=paste(pathout,'/recMat.txt',sep='')), silent=T);
+  #try(write.table(recMat,file=paste(pathout,'/recMat.txt',sep='')), silent=T);
 
   # write.table(dropMat_DLT,file=paste(pathout,'/dropMat_DLT.txt',sep=''));
   # write.table(dropMat_RND,file=paste(pathout,'/dropMat_RND.txt',sep=''));
@@ -342,7 +342,7 @@ if (loss.fun == 'default'){
   # write.table(DLT_cycle_rec, file=paste(pathout, "/DLT_cycle_rec.txt", sep=""))	  
   
   #plot dose Trace
-  pdf(file=paste(pathout,'/doseTrace.pdf',sep=''));
+  #pdf(file=paste(pathout,'/doseTrace.pdf',sep=''));
   for (k in 1:numTrials) {
     plot(as.factor(1:length(doseTrace_AllTrials[[k]])), doseTrace_AllTrials[[k]], type='b', xlab="cohort", ylab="dose", main=paste("Trial", k),ylim=c(0,5))
   }
